#_________________R Code Associated with Osteopathology in Rhinos Project_____________________#

#Authors: Kelsey Stilson (stilson@utexas.edu), S.S.B. Hopkins, Edward Byrd Davis
#2014


library(ape)
library(paleotree)
library(phytools)
setwd("~/YourDirectory")


--------------------------### Constructing Trees ###-------------------------------


#Trees were initially constructed in PAUP (for Adams Tree) and Mr.Bayes 3.1.2x86 using characters from Cerdeño (1995) ("cerdeno1995.nex")
#The same pruned tree can be constructed from Cerdeño (1995), because initial branch length is overwritten during the tree calibration. 
#burn-in was set at 25%, with four chains and two independent runs. 
#The number of generations was set at ten-million

Adams<-read.nexus("RhinosAdams2.nex")

Strict<-read.nexus("RhinosStrt2.nex")

#Pruning
AdamsPruned<-drop.tip(Adams, c("Egysodontinae", "Hyracodontinae", "Teletaceras", "Aceratjeroi", "Penetrigonas", "Amphicaenopus", "Subhyracodon", "Floridaceras", "FAM95544", "Peraceras", "Ronzotherium", "Mesaceratherium", "Protaceratherium", "Pleuroceros", "Diaceratherium", "Brachypotherium","Prosantorhinus", "Alicornops", "Hoploaceratherium", "'Aceratjeroi,'", "Lartetotherium", "L.schleiermacheri", "Stephanorhinus", "Coleodonta", "Hispanotherium", "Begertherium", "Beliajevina", "Iranotherium", "Elasmotherium", "Ninxiatherium", "Acerorhinus", "Chilotherium", "Chilotheridium", "Aprotodon", "Gaindatherium", "Punjabitherium", "Rhinoceros", "Docerorhinus", "Ceratotherium", "Paradiceros"))
plot(AdamsPruned)

StrictPruned<-drop.tip(Strict, c("Egysodontinae", "Hyracodontinae", "Teletaceras", "Aceratjeroi", "Penetrigonas", "Amphicaenopus", "Subhyracodon", "Floridaceras", "FAM95544", "Peraceras", "Ronzotherium", "Mesaceratherium", "Protaceratherium", "Pleuroceros", "Diaceratherium", "Brachypotherium","Prosantorhinus", "Alicornops", "Hoploaceratherium", "'Aceratjeroi,'", "Lartetotherium", "L.schleiermacheri", "Stephanorhinus", "Coleodonta", "Hispanotherium", "Begertherium", "Beliajevina", "Iranotherium", "Elasmotherium", "Ninxiatherium", "Acerorhinus", "Chilotherium", "Chilotheridium", "Aprotodon", "Gaindatherium", "Punjabitherium", "Rhinoceros", "Docerorhinus", "Ceratotherium", "Paradiceros"))
plot(AdamsPruned)



-----------------------------###Time Calibrated Phylogeny### (following Bapst 2013)---------------------------------

Tree<-AdamsPruned
plot(Tree)

timeData <- read.table("RhinoDates.txt", header=F)

dimnames(timeData) = list(c("Hyrachyus", "Trigonias", "Diceratherium", "Menoceras", "Aphelops", "Teleoceras", "Diceros"), c("FAD", "LAD"))

layout(matrix(1:6,3,2));parOrig <- par(mar=c(3,2,1,2))

Tree2<-multi2di(Tree)

TC_Equal<-(timePaleoPhy(Tree2, timeData, type = "equal", vartime = 1, ntrees = 1, randres = FALSE, timeres = FALSE, add.term = FALSE, inc.term.adj = FALSE, node.mins = NULL))


#Other Variations of Time Calibration:

TC_Basic<-(ladderize(timePaleoPhy(Tree, timeData, type = "basic", vartime = NULL, ntrees = 1,
                                  randres = FALSE, timeres = TRUE, add.term = FALSE,
                                  inc.term.adj = FALSE, rand.obs = FALSE, node.mins = NULL,
                                  plot = TRUE)))
axisPhylo();text(x=50,y=23,"type=basic",adj=c(0,0.5),cex=1.2)
plot(ladderize(timePaleoPhy(Tree, timeData, type = "equal", vartime = 1, ntrees = 1,
                            randres = FALSE, timeres = FALSE, add.term = FALSE,
                            inc.term.adj = FALSE, rand.obs = FALSE, node.mins = NULL)))
axisPhylo();text(x=50,y=23,"type=basic",adj=c(0,0.5),cex=1.2)
plot(ladderize(timePaleoPhy(Tree, timeData, type = "aba", vartime = 1, ntrees = 1,
                            randres = FALSE, timeres = FALSE, add.term = FALSE,
                            inc.term.adj = FALSE, rand.obs = FALSE, node.mins = NULL)))
axisPhylo();text(x=50,y=23,"type=basic",adj=c(0,0.5),cex=1.2)
plot(ladderize(timePaleoPhy(Tree, timeData, type = "zlba", vartime = 1, ntrees = 1,
                            randres = FALSE, timeres = FALSE, add.term = FALSE,
                            inc.term.adj = FALSE, rand.obs = FALSE, node.mins = NULL)))
axisPhylo();text(x=50,y=23,"type=basic",adj=c(0,0.5),cex=1.2)
plot(ladderize(timePaleoPhy(Tree, timeData, type = "mbl", vartime = 1, ntrees = 1,
                            randres = FALSE, timeres = FALSE, add.term = FALSE,
                            inc.term.adj = FALSE, rand.obs = FALSE, node.mins = NULL)))
axisPhylo();text(x=50,y=23,"type=basic",adj=c(0,0.5),cex=1.2)
layout(1);par(parOrig)


write.nexus(TC_Equal, file="TC_AdamsMP.nex")

--------------------------### Independent Contrast Analysis ###---------------------------------------

#Import tip data and trees
mydata <- read.table("IC_forR3.csv", header=TRUE, sep=",")

tree<-read.nexus("TC_AdamsMP.nex")
#For Ape, tree needs to be fully dichotomous, so for the time calibrate tree analysis I chose used the Adams Consensus tree because it was fully dichotomous

#check if your tree is dichotomous
is.binary.tree(TC_tree)

   ---##Alternate Trees##----

#MP_tree<-read.nexus("RhinosMPAdams2.nex") #Dichotomous Maximum Parsimony tree. Not a very high power test here.

#Morpho_tree<-read.nexus("MORPHO_Tree1.nex") #Tree 1 chosen because it had the highest posterrior probability
#You could also write a loop to sample a subset of high-probability trees from your data, run the IC's, and average the total (thank you, Graham Slater)



#####Set up the contrast########

#Creating Numeric Vectors
#M13 (molars 1-3), F1 (average femur measurement 1) 
# and H5 (average humerus measurement 5) are all mass proxies.


M13 <- mydata$M13
H5 <- mydata$H5
F1 <- mydata$F1
Exostoses <- mydata$Exostoses
Lipping <- mydata$Lipping
Abnormal_Bone_Texture <- mydata$Abnormal_Bone_Texture
Cavitation <- mydata$Cavitation
Foramen_Shape <- mydata$Foramen_Shape
Foramen_Size_Variations <- mydata$Foramen_Size_Variations
Articular_Surface <- mydata$Articular_Surface
FemurHum <- mydata$FemurHum
Podials <- mydata$Podials
Overall_Path <- mydata$Overall_Path
YN <- mydata$YN


#Correlating Tips

names(M13) <- row.names(M13)
names(H5) <- row.names(H5)
names(F1) <- row.names(F1)
names(Exostoses) <- row.names(Exostoses)
names(Lipping) <- row.names(Lipping)
names(Abnormal_Bone_Texture) <- row.names(Abnormal_Bone_Texture)
names(Cavitation) <- row.names(Cavitation)
names(Foramen_Shape) <- row.names(Foramen.Shape)
names(Foramen_Size_Variations) <- row.names(Foramen_Size_Variations)
names(Articular_Surface) <- row.names(Articular_Surface)
names(FemurHum) <- row.names(FemurHum)
names(Podials) <- row.names(Podials)
names(Vertebrae) <- row.names(Vertebrae)
names(Overall_Path) <- row.names(Overall_Path)
names(YN) <- row.names(YN)



###########Run the contrast#################

ContrastM13 <- pic(M13, tree, var.contrasts = FALSE)
ContrastH5 <- pic(H5, tree, var.contrasts = FALSE)
ContrastF1 <- pic(F1, tree, var.contrasts = FALSE)
ContrastExostoses <- pic(Exostoses, tree, var.contrasts=FALSE)
ContrastAbnormal_Bone_Texture <- pic(Abnormal_Bone_Texture, tree, var.contrasts=FALSE)
ContrastRemodeling <- pic(Remodeling, tree, var.contrasts=FALSE)
ContrastCavitation <- pic(Cavitation, tree, var.contrasts=FALSE)
ContrastForamen_Shape <- pic(Foramen_Shape, tree, var.contrasts=FALSE)
ContrastForamen_Size_Variations <- pic(Foramen_Size_Variations, tree, var.contrasts=FALSE)
ContrastArticular_Surface <- pic(Articular_Surface, tree, var.contrasts=FALSE)
ContrastFemurHum <- pic(FemurHum, tree, var.contrasts=FALSE)
ContrastPodials <- pic(Podials, tree, var.contrasts=FALSE)
ContrastOverall_Path <- pic(Overall_Path, tree, var.contrasts=FALSE)
ContrastYN <- pic(Overall_Path, tree, var.contrasts=FALSE)


##########DATA ANALYSIS############
-----##Linear Regressions without adjusting for phylogeny (no Independent Contrast)
LM_Exostoses <- summary(lm(M13~Exostoses))
LM_Lipping <- summary(lm(M13~Lipping))
LM_Abnormal_Bone_Texture <- summary(lm(M13~Abnormal_Bone_Texture))
LM_Cavitation <- summary(lm(M13~Cavitation))
LM_Foramen_Shape <- summary(lm(M13~Foramen_Shape))
LM_Foramen_Size_Variations <- summary(lm(M13~Foramen_Size_Variations))
LM_Articular_Surface <- summary(lm(M13~Articular_Surface))
LM_PodialsVsFemurHum <-summary(lm(Podials~FemurHum))
LM_Overall_Path <- summary(lm(M13~Overall_Path))
LM_YN <- summary(lm(M13~YN))




-----##Independent Contrasts##----
#Perform Linear Regression against Mass and extract adjusted r squared values 
#note: add $adj.r.squared for to extract adjusted r squared values for data frame (below)
#see example with H5 and F1 independent contrasts 


RegressExostoses <- summary(lm(ContrastM13~ContrastExtoses))
RegressLipping <- summary(lm(ContrastM13~ContrastLipping))
RegressAbnormal_Bone_Texture <- summary(lm(ContrastM13~ContrastAbnormal_Bone_Texture))
RegressCavitation <- summary(lm(ContrastM13~ContrastCavitation))
RegressForamen_Shape <- summary(lm(ContrastM13~ContrastForamen_Shape))
RegressForamen_Size_Variations <- summary(lm(ContrastM13~ContrastForamen_Size_Variations))
RegressArticular_Surface <- summary(lm(ContrastM13~ContrastArticular_Surface))
RegressPodialsVsFemurHum <-summary(lm(ContrastPodials~ContrastFemurHum))
RegressOverall_Path <- summary(lm(ContrastM13~ContrastOverall_Path))
RegressYN <- summary(lm(ContrastM13~ContrastYN))

#PerformLinear Regression against H5 and extract adjusted r squared values
RegressYN2 <- summary(lm(ContrastH5~ContrastYN))$adj.r.squared
RegressExtoses2 <- summary(lm(ContrastH5~ContrastExtoses))$adj.r.squared
RegressLipping2 <- summary(lm(ContrastH5~ContrastLipping))$adj.r.squared
RegressAbnormal_Bone_Texture2 <- summary(lm(ContrastH5~ContrastAbnormal_Bone_Texture))$adj.r.squared
RegressCavitation2 <- summary(lm(ContrastH5~ContrastCavitation))$adj.r.squared
RegressForamen_Shape2 <- summary(lm(ContrastH5~ContrastForamen_Shape))$adj.r.squared
RegressForamen_Size_Variations2 <- summary(lm(ContrastH5~ContrastForamen_Size_Variations))$adj.r.squared
RegressArticular_Surface2 <- summary(lm(ContrastH5~ContrastArticular_Surface))$adj.r.squared
RegressOverall_Path2 <- summary(lm(ContrastH5~ContrastOverall_Path))$adj.r.squared
RegressYN2 <- summary(lm(ContrastH5~ContrastYN))$adj.r.squared

#PerformLinear Regression against F1 and extract adjusted r squared values
RegressYN3 <- summary(lm(ContrastF1~ContrastYN))$adj.r.squared
RegressExtoses3 <- summary(lm(ContrastF1~ContrastExostoses))$adj.r.squared
RegressLipping3 <- summary(lm(ContrastF1~ContrastLipping))$adj.r.squared
RegressAbnormal_Bone_Texture3 <- summary(lm(ContrastF1~ContrastAbnormal_Bone_Texture))$adj.r.squared
RegressCavitation3 <- summary(lm(ContrastF1~ContrastCavitation))$adj.r.squared
RegressForamen_Shape3 <- summary(lm(ContrastF1~ContrastForamen_Shape))$adj.r.squared
RegressForamen_Size_Variations3 <- summary(lm(ContrastF1~ContrastForamen_Size_Variations))$adj.r.squared
RegressArticular_Surface3 <- summary(lm(ContrastF1~ContrastArticular_Surface))$adj.r.squared
RegressOverall_Path3 <- summary(lm(ContrastF1~ContrastOverall_Path))$adj.r.squared
RegressYN3 <- summary(lm(ContrastF1~ContrastYN))$adj.r.squared

#Make Table of adjusted R squared Values (if all adj.r.squared values have been selected out)
DataFrame <- data.frame(RegressYN, RegressExtoses, RegressLipping, RegressAbnormal_Bone_Texture, RegressCavitation, 
                        RegressForamen_Shape, RegressForamen_Size_Variations, 
                        RegressArticular_Surface,RegressOverall_Path, RegressPodialsVsFemurHum, 
                        RegressYN2, RegressExtoses2, RegressLipping2, RegressAbnormal_Bone_Texture2,
                        RegressErosions2, RegressForamen_Shape2,
                        RegressForamen_Size_Variations2, RegressArticular_Surface2,
                        RegressOverall_Path2, RegressYN3, RegressExtoses3, RegressLipping3, RegressAbnormal_Bone_Texture3,
                        RegressCavitation3, RegressForamen_Shape3,RegressForamen_Size_Variations3, 
                        RegressArticular_Surface3,RegressOverall_Path3)


DataFrame_LM <- data.frame(LM_YN, LM_Extoses, LM_Lipping, LM_Abnormal_Bone_Texture, LM_Cavitation, 
                            LM_Foramen_Shape, LM_Foramen_Size_Variations, 
                            LM_Articular_Surface, LM_Overall_Path, LM_PodialsVsFemurHum)


DataFrame
DataFrame_LM

summary.lm(RegressYN)
plot(RegressYN)
abline(RegressYN)

write.table(DataFrame, "Rhino_Regressions_adj_Rsq.txt", sep="\t")

#saving trees
write.tree(TreeName, file="MyTreefile.tre")
write.nexus(TreeName, file="MyNexusTreefile.nex")

--------------------------------------------------------------------------------------------------------------------------
  #References
  #Bapst, D. W. 2013. A stochastic rate-calibrated method for time-scaling phylogenies of fossil taxa. Methods in Ecology and Evolution, 4(8), 724-733
  #Cerdeno, E. 1995. Cladistic analysis of the family Rhinocerotidae. American Museum Novitates, 3143:1-25. New York, New York.
  #Rambaut, A. 2009. Tracer 1.5 http://tree.bio.ed.ac.uk/software/tracer/
  #Ronquist, F. and J. P. Huelsenbeck. 2003. MRBAYES 3: Bayesian phylogenetic inference under mixed models. Bioinformatics 19:1572-1574